@@ -1,7 +1,7 @@
 //! Implementation of simple continued fractions
 
 use super::block::{Block, DualBlock};
-use crate::quadratic::surd::{QuadraticSurd, QuadraticSurdBase};
+use crate::quadratic::{QuadraticBase, surd::QuadraticSurd};
 use crate::traits::{Approximation, Computable, WithSigned, WithUnsigned};
 use core::convert::TryFrom;
 use core::str::FromStr;
@@ -210,7 +210,7 @@ impl<U> ContinuedFraction<U> {
 
         if matches!(negative, None) {
             if matches!(p_coeffs.first(), Some(p) if p <= &T::zero()) {
-                // TODO (v0.2): how to handle negative coefficients in the periodic parts
+                // TODO: how to handle negative coefficients in the periodic parts
                 unimplemented!()
             } else {
                 negative = Some(negate);
@@ -513,7 +513,7 @@ impl<T: Zero> ContinuedFraction<T> {
 }
 
 impl<
-        T: QuadraticSurdBase + AddAssign + WithUnsigned<Unsigned = U>,
+        T: QuadraticBase + AddAssign + WithUnsigned<Unsigned = U>,
         U: Integer + Clone + NumRef + CheckedAdd + CheckedMul + WithSigned<Signed = T>,
     > Zero for ContinuedFraction<U>
 where
@@ -532,7 +532,7 @@ where
 }
 
 impl<
-        T: QuadraticSurdBase + AddAssign + WithUnsigned<Unsigned = U>,
+        T: QuadraticBase + AddAssign + WithUnsigned<Unsigned = U>,
         U: Integer + Clone + NumRef + CheckedAdd + CheckedMul + WithSigned<Signed = T>,
     > One for ContinuedFraction<U>
 where
@@ -610,7 +610,7 @@ impl<T: Integer + Clone + WithUnsigned<Unsigned = U>, U: Zero> From<Ratio<T>>
     }
 }
 
-// TODO (v0.2): expose this after implemented
+// TODO: expose this after implemented
 mod parse {
     use super::{ContinuedFraction, FromStr};
 
@@ -721,7 +721,7 @@ impl<T: Zero> Neg for ContinuedFraction<T> {
 }
 
 impl<
-        T: QuadraticSurdBase + AddAssign + WithUnsigned<Unsigned = U>,
+        T: QuadraticBase + AddAssign + WithUnsigned<Unsigned = U>,
         U: Integer + Clone + NumRef + CheckedAdd + CheckedMul + WithSigned<Signed = T>,
     > Mul<T> for ContinuedFraction<U>
 where
@@ -740,7 +740,7 @@ where
 }
 
 impl<
-        T: QuadraticSurdBase + AddAssign + WithUnsigned<Unsigned = U>,
+        T: QuadraticBase + AddAssign + WithUnsigned<Unsigned = U>,
         U: Integer + Clone + NumRef + CheckedAdd + CheckedMul + WithSigned<Signed = T>,
     > Div<T> for ContinuedFraction<U>
 where
@@ -761,7 +761,7 @@ where
 macro_rules! impl_binop_for_ratio_surd {
     (impl $imp:ident, $method:ident) => {
         impl<
-                T: QuadraticSurdBase + AddAssign + WithUnsigned<Unsigned = U>,
+                T: QuadraticBase + AddAssign + WithUnsigned<Unsigned = U>,
                 U: Integer + Clone + NumRef + CheckedAdd + CheckedMul + WithSigned<Signed = T>,
             > $imp<Ratio<T>> for ContinuedFraction<U>
         where
@@ -780,7 +780,7 @@ macro_rules! impl_binop_for_ratio_surd {
         }
 
         impl<
-                T: QuadraticSurdBase + AddAssign + WithUnsigned<Unsigned = U>,
+                T: QuadraticBase + AddAssign + WithUnsigned<Unsigned = U>,
                 U: Integer + Clone + NumRef + CheckedAdd + CheckedMul + WithSigned<Signed = T>,
             > $imp<ContinuedFraction<U>> for ContinuedFraction<U>
         where
@@ -959,7 +959,7 @@ where
 /// continued fraction. This can be used for accepting high-precision
 /// decimal, or infinite continued fraction representation
 trait ParseContinuedFraction {
-    // TODO: implement followings
+    // TODO: implement followings and make the trait public
     // fn parse_as_decimals() -> InfiniteContinuedFraction;
     // fn parse_as_cfrac() -> InfiniteContinuedFraction;
 }
@@ -1094,7 +1094,7 @@ mod tests {
 
     #[test]
     fn cont_frac_arithmetic_test() {
-        // TODO (v0.2): add more tests to cover all cases
+        // TODO: add more tests to cover all cases
 
         let one = ContinuedFraction::one();
         let n_one = ContinuedFraction::<u32>::new(vec![1], vec![], true);
